@@ -15,9 +15,11 @@ __all__ = [
 
 HOSTNAME = '{}.terminals.homeinfo.intra'
 PACMAN = '/usr/bin/pacman'
-SSH_OPTIONS = (
-    'LogLevel=error', 'UserKnownHostsFile=/dev/null',
-    'StrictHostKeyChecking=no', 'ConnectTimeout=5'
-)
+SSH_OPTIONS = [
+    'LogLevel=error',
+    'UserKnownHostsFile=/dev/null',
+    'StrictHostKeyChecking=no',
+    'ConnectTimeout=5'
+]
 SUDO = '/usr/bin/sudo'
 SYSTEMCTL = '/usr/bin/systemctl'
