@@ -2,8 +2,6 @@
 
 from argparse import Namespace
 from datetime import datetime
-from multiprocessing.managers import DictProxy
-from typing import NamedTuple, Tuple
 
 from homeinfotools.logging import syslogger
 from homeinfotools.rpc.exceptions import SSHConnectionError
@@ -15,12 +13,16 @@ from homeinfotools.rpc.sysupgrade import sysupgrade
 __all__ = ['Worker']
 
 
-class Worker(NamedTuple):
+class Worker:   # pylint: disable=R0903
     """Stored args and manager to process systems."""
 
-    args: Namespace
+    __slots__ = ('args',)
 
-    def __call__(self, system: int) -> Tuple[int, DictProxy]:
+    def __init__(self, args: Namespace):
+        """Sets the command line arguments."""
+        self.args = args
+
+    def __call__(self, system: int) -> tuple[int, dict]:
         """Runs the worker on the given system."""
         start = datetime.now()
         result = {'start': start.isoformat()}
